@@ -1,7 +1,7 @@
 #![allow(dead_code)]
 use crate::reference_tables;
 use crate::structs::*;
-use crate::transformation::*;
+use crate::transformation::TransformationMatrix;
 use std::cmp::Ordering;
 use std::fmt;
 use std::sync::atomic::{AtomicUsize, Ordering as AtomicOrdering};
@@ -14,7 +14,7 @@ static ATOM_COUNTER: AtomicUsize = AtomicUsize::new(0);
 pub struct Atom {
     /// The unique serial number given to this atom
     counter: usize,
-    /// Determines if this atom is an hetero atom (true), a non standard atom, or a normal atom (false)
+    /// Determines if this atom is a hetero atom (true), a non standard atom, or a normal atom (false)
     hetero: bool,
     /// The serial number of the Atom, should be unique within its model
     serial_number: usize,
@@ -40,6 +40,7 @@ pub struct Atom {
 
 impl Atom {
     /// Create a new Atom
+    #[must_use]
     #[allow(clippy::too_many_arguments)]
     pub fn new(
         hetero: bool,
@@ -82,28 +83,29 @@ impl Atom {
         }
     }
 
-    /// Get the unique immutable counter for this atom
+    /// Get a unique immutable counter for this atom.
     pub(crate) fn counter(&self) -> usize {
         self.counter
     }
 
-    /// Get if this atom is an hetero atom (`true`), a non standard atom, or a normal atom (`false`)
+    /// Determine if this atom is an hetero atom (`true`), a non standard atom, or a normal atom (`false`).
     pub fn hetero(&self) -> bool {
         self.hetero
     }
 
-    /// Set if this atom is an hetero atom (`true`), a non standard atom, or a normal atom (`false`)
+    /// Set whether this atom is an hetero atom (`true`), a non standard atom, or a normal atom (`false`).
     pub fn set_hetero(&mut self, new_hetero: bool) {
         self.hetero = new_hetero
     }
 
     /// Get the position of the atom as a tuple of `f64`, in the following order: (x, y, z).
-    /// Given in Aͦ as defined by PDB, to be specific in the orthogonal coordinate system.
+    /// Given in Å as defined by PDB in the orthogonal coordinate system.
     pub fn pos(&self) -> (f64, f64, f64) {
         (self.x, self.y, self.z)
     }
 
     /// Set the position of the atom as a tuple of `f64`, in the following order: (x, y, z).
+    /// # Errors
     /// It fails if one or more of the numbers is not finite (`f64.is_finite()`).
     pub fn set_pos(&mut self, new_pos: (f64, f64, f64)) -> Result<(), String> {
         if new_pos.0.is_finite() && new_pos.1.is_finite() && new_pos.2.is_finite() {
@@ -120,13 +122,14 @@ impl Atom {
     }
 
     /// Get the X position of the atom.
-    /// Given in Aͦ as defined by PDB, to be specific in the orthogonal coordinate system.
+    /// Given in Å as defined by PDB in the orthogonal coordinate system.
     /// This number has a precision of 8.3 in PDB files and 5 decimal places of precision in mmCIF files.
     pub fn x(&self) -> f64 {
         self.x
     }
 
-    /// Set the X position of the atom in Aͦ.
+    /// Set the X position of the atom in Å.
+    /// # Errors
     /// It fails if `new_pos` is not finite (`f64.is_finite()`).
     pub fn set_x(&mut self, new_pos: f64) -> Result<(), String> {
         if new_pos.is_finite() {
@@ -141,13 +144,14 @@ impl Atom {
     }
 
     /// Get the Y position of the atom.
-    /// Given in Aͦ as defined by PDB, to be specific in the orthogonal coordinate system.
+    /// Given in Å as defined by PDB in the orthogonal coordinate system.
     /// This number has a precision of 8.3 in PDB files and 5 decimal places of precision in mmCIF files.
     pub fn y(&self) -> f64 {
         self.y
     }
 
-    /// Set the Y position of the atom.
+    /// Set the Y position of the atom in Å.
+    /// # Errors
     /// It fails if `new_pos` is not finite (`f64.is_finite()`).
     pub fn set_y(&mut self, new_pos: f64) -> Result<(), String> {
         if new_pos.is_finite() {
@@ -162,13 +166,14 @@ impl Atom {
     }
 
     /// Get the Z position of the atom.
-    /// Given in Aͦ as defined by PDB, to be specific in the orthogonal coordinate system.
+    /// Given in Å as defined by PDB in the orthogonal coordinate system.
     /// This number has a precision of 8.3 in PDB files and 5 decimal places of precision in mmCIF files.
     pub fn z(&self) -> f64 {
         self.z
     }
 
-    /// Set the Z position of the atom.
+    /// Set the Z position of the atom in Å.
+    /// # Errors
     /// It fails if `new_pos` is not finite (`f64.is_finite()`).
     pub fn set_z(&mut self, new_pos: f64) -> Result<(), String> {
         if new_pos.is_finite() {
@@ -183,38 +188,42 @@ impl Atom {
     }
 
     /// Get the serial number of the atom.
-    /// This number combined with the alt_loc from the Conformer of this Atom is defined to be unique in the containing model, which is not enforced.
-    /// THe precision of this number is 5 digits in PDB files.
+    /// This number, combined with the `alt_loc` from the Conformer of this Atom, is defined to be unique in the containing model, which is not enforced.
+    /// The precision of this number is 5 digits in PDB files.
+    /// If more than 99,999 atoms are present in the same model, the internal numbering will
+    /// continue counting up even if the file from which the atoms were read does not.
+    /// Importantly, this will not affect the saving of the file, only the internal handling of
+    /// atom serial numbers.
     pub fn serial_number(&self) -> usize {
         self.serial_number
     }
 
     /// Set the serial number of the atom.
-    /// This number combined with the alt_loc from the Conformer of this Atom is defined to be unique in the containing model, which is not enforced.
+    /// This number, combined with the `alt_loc` from the Conformer, of this Atom is defined to be unique in the containing model, which is not enforced.
     pub fn set_serial_number(&mut self, new_serial_number: usize) {
         self.serial_number = new_serial_number;
     }
 
     /// Get the name of the atom. The name will be trimmed (whitespace removed) and changed to ASCII uppercase.
-    /// For PDB files the name is max 4 characters.
     pub fn name(&self) -> &str {
         &self.name
     }
 
     /// Set the name of the atom. The name will be trimmed (whitespace removed) and changed to ASCII uppercase as requested by PDB/PDBx standard.
-    /// For PDB files the name can at most contain 4 characters.
-    /// If the name is invalid an error message is provided.
+    /// For PDB files the name can at most contain 4 characters, enforced when saving the file.
+    /// # Errors
     /// The name can only contain valid characters, the ASCII graphic characters (`char.is_ascii_graphic() || char == ' '`).
+    /// If the name is invalid an error message is provided.
     pub fn set_name(&mut self, new_name: impl Into<String>) -> Result<(), String> {
         let new_name = new_name.into();
-        if !valid_identifier(&new_name) {
+        if valid_identifier(&new_name) {
+            self.name = new_name.trim().to_ascii_uppercase();
+            Ok(())
+        } else {
             Err(format!(
                 "New name has invalid characters for atom {} name {}",
                 self.serial_number, new_name
             ))
-        } else {
-            self.name = new_name.trim().to_ascii_uppercase();
-            Ok(())
         }
     }
 
@@ -225,6 +234,7 @@ impl Atom {
     }
 
     /// Set the occupancy or Q factor of the atom.
+    /// # Errors
     /// It fails if `new_occupancy` is not finite (`f64.is_finite()`) or if it is negative.
     pub fn set_occupancy(&mut self, new_occupancy: f64) -> Result<(), String> {
         if new_occupancy.is_finite() {
@@ -254,6 +264,7 @@ impl Atom {
     }
 
     /// Set the B factor or temperature factor of the atom.
+    /// # Errors
     /// It fails if `new_b_factor` is not finite (`f64.is_finite()`) or if it is negative.
     pub fn set_b_factor(&mut self, new_b_factor: f64) -> Result<(), String> {
         if new_b_factor.is_finite() {
@@ -281,27 +292,29 @@ impl Atom {
     }
 
     /// Set the element of this atom. The element will be trimmed (whitespace removed) and changed to ASCII uppercase as requested by PDB/PDBx standard.
-    /// For PDB files the element can at most contain 2 characters.
-    /// If the element is invalid an error message is provided.
+    /// For PDB files the element can at most contain 2 characters, enforced when saving the file.
+    /// # Errors
     /// The element can only contain valid characters, the ASCII graphic characters (`char.is_ascii_graphic() || char == ' '`).
+    /// If the element is invalid an error message is provided.
     pub fn set_element(&mut self, new_element: impl Into<String>) -> Result<(), String> {
         let new_element = new_element.into();
-        if !valid_identifier(&new_element) {
+        if valid_identifier(&new_element) {
+            self.element = new_element.trim().to_ascii_uppercase();
+            Ok(())
+        } else {
             Err(format!(
                 "New element has invalid characters for atom {} name {}",
                 self.serial_number, new_element
             ))
-        } else {
-            self.element = new_element.trim().to_ascii_uppercase();
-            Ok(())
         }
     }
 
-    /// Get the atomic number of this Atom. If defined it uses `self.element()`, otherwise it uses `self.name()`, if that still does not
+    /// Get the atomic number of this Atom. If defined, it uses `self.element()`, otherwise it uses `self.name()`, if that still does not
     /// find anything it uses the first character of `self.name()` if that is one of "CHONS". This could potentially lead to misclassifications
-    /// but in most cases should result in the correct element. Otherwise, the element is a required part in the PDB file so not specifying it
-    /// is fair to lead to unspecified behaviour.
-    /// It fails when `self.element()` is not an element in the periodic table, or if `self.element()` is undefined and `self.name()` is not an element in the periodic table.
+    /// but in most cases should result in the correct element. It should be noted that the element is a required part in the PDB file so not specifying it
+    /// is likely to lead to unspecified behaviour.
+    /// # Errors
+    /// It returns `None` if `self.element()` is not an element in the periodic table, or if `self.element()` is undefined and `self.name()` is not an element in the periodic table.
     pub fn atomic_number(&self) -> Option<usize> {
         if !self.element.is_empty() {
             reference_tables::get_atomic_number(self.element())
@@ -325,48 +338,47 @@ impl Atom {
     /// Chemistry - A European Journal, 22(41):14625–14632, oct 2016. URL: <http://doi.org/10.1002/chem.201602949>.
     /// Updated to the corrigendum: <https://doi.org/10.1002/chem.201700610>.
     ///
-    /// It fails if the atomic number of this Atom is not defined (see `self.atomic_number()`).
-    /// It also fails when the atomic radius is not defined for the given atomic number, so if the atomic
+    /// It returns `None` if the atomic number of this Atom is not defined (see `self.atomic_number()`).
+    /// The same is true if the atomic radius is not defined for the given atomic number, i.e. if the atomic
     /// number is higher than 96.
     pub fn atomic_radius(&self) -> Option<f64> {
         self.atomic_number()
-            .map(reference_tables::get_atomic_radius)
-            .flatten()
+            .and_then(reference_tables::get_atomic_radius)
     }
 
     /// Get the van der Waals radius for this Atom in Å. The radius is defined up to element 'Es' or atomic number 99.
     /// Source: Alvarez, S. (2013). A cartography of the van der Waals territories. Dalton Transactions, 42(24), 8617. <https://doi.org/10.1039/c3dt50599e>.
     ///
-    /// It fails if the atomic number of this Atom is not defined (see `self.atomic_number()`).
-    /// It also fails when the atomic radius is not defined for the given atomic number, so if the atomic
+    /// It returns `None` if the atomic number of this Atom is not defined (see `self.atomic_number()`).
+    /// The same is true if the atomic radius is not defined for the given atomic number, i.e. if the atomic
     /// number is higher than 99.
     pub fn vanderwaals_radius(&self) -> Option<f64> {
         self.atomic_number()
-            .map(reference_tables::get_vanderwaals_radius)
-            .flatten()
+            .and_then(reference_tables::get_vanderwaals_radius)
     }
 
     /// Gets the covalent bond radii for this Atom.
-    /// The result is the radius for a single, double and triple bond, where the last two are optional. If the radius for a double bond is unknown the radius for a triple bond is also unknown.
+    /// The result is the radius for a single, double and triple bond, where the last two are optional. If the radius for a double bond is unknown, the radius for a triple bond is also unknown.
     /// All values are given in Å.
     /// Sources:
     ///  * P. Pyykkö; M. Atsumi (2009). "Molecular Single-Bond Covalent Radii for Elements 1-118". Chemistry: A European Journal. 15 (1): 186–197. <https://doi.org/10.1002/chem.200800987>
     ///  * P. Pyykkö; M. Atsumi (2009). "Molecular Double-Bond Covalent Radii for Elements Li–E112". Chemistry: A European Journal. 15 (46): 12770–12779. <https://doi.org/10.1002/chem.200901472>
     ///  * P. Pyykkö; S. Riedel; M. Patzschke (2005). "Triple-Bond Covalent Radii". Chemistry: A European Journal. 11 (12): 3511–3520. <https://doi.org/10.1002/chem.200401299>
     ///
-    /// It fails if the atomic number of this Atom is not defined (see `self.atomic_number()`).
+    /// It returns `None` if the atomic number of this Atom is not defined (see `self.atomic_number()`).
     pub fn covalent_bond_radii(&self) -> Option<(f64, Option<f64>, Option<f64>)> {
         self.atomic_number()
             .map(reference_tables::get_covalent_bond_radii)
     }
 
-    /// Get the charge of the atom.
+    /// Get the charge of this atom.
     /// In PDB files the charge is one digit with a sign.
     pub fn charge(&self) -> isize {
         self.charge
     }
 
     /// Set the charge of this atom.
+    /// In PDB files the charge is one digit with a sign.
     pub fn set_charge(&mut self, new_charge: isize) {
         self.charge = new_charge;
     }
@@ -400,20 +412,20 @@ impl Atom {
         self.atf = Some(factors);
     }
 
-    /// Get if this atom is likely to be a part of the backbone of a protein.
-    /// This is based on this Atom only, for a more precise definition use [hierarchy::ContainsAtomConformer]`.is_backbone()`.
+    /// Determine whether this atom is likely to be a part of the backbone of a protein.
+    /// This is based on this Atom only, for a more precise definition use [`hierarchy::ContainsAtomConformer::is_backbone`].
     pub fn is_backbone(&self) -> bool {
         reference_tables::is_backbone(self.name())
     }
 
-    /// Apply a transformation to the position of this atom, the new position is immediately set.
+    /// Apply a transformation using a given `TransformationMatrix` to the position of this atom, the new position is immediately set.
     pub fn apply_transformation(&mut self, transformation: &TransformationMatrix) {
         self.set_pos(transformation.apply(self.pos()))
             .expect("Some numbers were invalid in applying a transformation");
     }
 
     /// See if the `other` Atom corresponds with this Atom.
-    /// Which means that the Atoms are equal except for the position, occupancy, and b_factor.
+    /// This means that the Atoms are equal except for the position, occupancy, and b_factor.
     /// Used to validate that multiple models contain the same atoms, but with different positional data.
     pub fn corresponds(&self, other: &Atom) -> bool {
         self.serial_number == other.serial_number
@@ -430,9 +442,8 @@ impl Atom {
             .sqrt()
     }
 
-    /// Gives the distance between the centers of two atoms in Aͦ.
-    /// Wrapping around the unit cell if needed.
-    /// Meaning it will give the shortest distance between the two atoms or any of their copies given a crystal of the size of the given unit cell stretching out to all sides.
+    /// Gives the distance between the centers of two atoms in Aͦ, wrapping around the unit cell if needed.
+    /// This will give the shortest distance between the two atoms or any of their copies given a crystal of the size of the given unit cell stretching out to all sides.
     pub fn distance_wrapping(&self, other: &Atom, cell: &UnitCell) -> f64 {
         let mut x = other.x;
         if (self.x - other.x).abs() > cell.a() / 2.0 {
@@ -464,41 +475,98 @@ impl Atom {
         ((x - self.x).powi(2) + (y - self.y).powi(2) + (z - self.z).powi(2)).sqrt()
     }
 
-    /// Checks if this Atom overlaps with the given atom. It overlaps if the distance between the atoms is
-    /// less then the sum of the radius from this atom and the other atom. The used radius is (`atom.atomic_radius()`).
+    #[allow(clippy::similar_names)]
+    /// Gives the angle between the centers of three atoms in degrees.
+    /// The angle is calculated as the angle between the two lines that include
+    /// atoms [1, 2] and [2, 3]
+    pub fn angle(&self, atom2: &Atom, atom3: &Atom) -> f64 {
+        let (a, b, c) = (self.pos(), atom2.pos(), atom3.pos());
+
+        // Form the two vectors
+        let ba = [a.0 - b.0, a.1 - b.1, a.2 - b.2];
+        let bc = [c.0 - b.0, c.1 - b.1, c.2 - b.2];
+
+        // Calculate absolute values of vectors
+        let abs_ba = ba.iter().fold(0.0, |acc, x| acc + (x * x)).sqrt();
+        let abs_bc = bc.iter().fold(0.0, |acc, x| acc + (x * x)).sqrt();
+
+        // Form dot product between vecs
+        let dot = ba
+            .iter()
+            .zip(bc.iter())
+            .fold(0.0, |acc, (a, b)| acc + (a * b));
+
+        // Calculate angle from all ingredients
+        (dot / (abs_ba * abs_bc)).acos().to_degrees()
+    }
+
+    #[allow(clippy::similar_names)]
+    /// Gives the dihedral between the centers of four atoms in degrees.
+    /// The angle is calculated as the angle between the two planes spanned by
+    /// atoms [1, 2, 3] and [2, 3, 4].
+    pub fn dihedral(&self, atom2: &Atom, atom3: &Atom, atom4: &Atom) -> f64 {
+        let (a, b, c, d) = (self.pos(), atom2.pos(), atom3.pos(), atom4.pos());
+
+        // Form vectors
+        let ba = [a.0 - b.0, a.1 - b.1, a.2 - b.2];
+        let bc = [c.0 - b.0, c.1 - b.1, c.2 - b.2];
+        let cb = [b.0 - c.0, b.1 - c.1, b.2 - c.2];
+        let cd = [d.0 - c.0, d.1 - c.1, d.2 - c.2];
+
+        // Form two normal vectors via cross products
+        let n1 = [
+            ba[1] * bc[2] - ba[2] * bc[1],
+            ba[2] * bc[0] - ba[0] * bc[2],
+            ba[0] * bc[1] - ba[1] * bc[0],
+        ];
+        let n2 = [
+            cb[1] * cd[2] - cb[2] * cd[1],
+            cb[2] * cd[0] - cb[0] * cd[2],
+            cb[0] * cd[1] - cb[1] * cd[0],
+        ];
+
+        // calculate abs of vecs
+        let abs_n1 = n1.iter().fold(0.0, |acc, x| acc + (x * x)).sqrt();
+        let abs_n2 = n2.iter().fold(0.0, |acc, x| acc + (x * x)).sqrt();
+
+        let dot = n1
+            .iter()
+            .zip(n2.iter())
+            .fold(0.0, |acc, (a, b)| acc + (a * b));
+        (dot / (abs_n1 * abs_n2)).acos().to_degrees()
+    }
+
+    /// Checks whether this Atom overlaps with the given atom. It overlaps if the distance between the atoms is
+    /// less then the sum of the radii of this atom and the other atom. The used radius is (`atom.atomic_radius()`).
     ///
-    /// Note: the atomic radius used in the unbound radius, this is in most cases bigger than the bound radius
+    /// Note: the atomic radius used is the unbound radius, this is in most cases bigger than the bound radius
     /// and as such can result in false positives.
     ///
-    /// It fails if for any one of the two atoms the radius (`atom.atomic_radius()`) is not defined.
+    /// It returns `None` if, for any one of the two atoms, the radius (`atom.atomic_radius()`) is not defined.
     pub fn overlaps(&self, other: &Atom) -> Option<bool> {
-        self.atomic_radius()
-            .map(|self_rad| {
-                other
-                    .atomic_radius()
-                    .map(|other_rad| self.distance(other) <= self_rad + other_rad)
-            })
-            .flatten()
+        self.atomic_radius().and_then(|self_rad| {
+            other
+                .atomic_radius()
+                .map(|other_rad| self.distance(other) <= self_rad + other_rad)
+        })
     }
 
     /// Checks if this Atom overlaps with the given atom. It overlaps if the distance between the atoms is
-    /// less then the sum of the radius from this atom and the other atom. The used radius is (`atom.atomic_radius()`).
-    /// Wrapping around the unit cell if needed. Meaning it will give the shortest distance between the two
+    /// less then the sum of the radii of this atom and the other atom, wrapping around the unit cell if needed.
+    /// The used radius is (`atom.atomic_radius()`). This will give the shortest distance between the two
     /// atoms or any of their copies given a crystal of the size of the given unit cell stretching out to
     /// all sides.
     ///
-    /// Note: the atomic radius used in the unbound radius, this is in most cases bigger than the bound radius
+    /// Note: the atomic radius used is the unbound radius, this is in most cases bigger than the bound radius
     /// and as such can result in false positives.
     ///
     /// It fails if for any one of the two atoms the radius (`atom.atomic_radius()`) is not defined.
     pub fn overlaps_wrapping(&self, other: &Atom, cell: &UnitCell) -> Option<bool> {
-        self.atomic_radius()
-            .map(|self_rad| {
-                other
-                    .atomic_radius()
-                    .map(|other_rad| self.distance_wrapping(other, cell) <= self_rad + other_rad)
-            })
-            .flatten()
+        self.atomic_radius().and_then(|self_rad| {
+            other
+                .atomic_radius()
+                .map(|other_rad| self.distance_wrapping(other, cell) <= self_rad + other_rad)
+        })
     }
 
     /// Checks if this Atom overlaps with the given atom. It overlaps if the distance between the atoms is
@@ -509,33 +577,29 @@ impl Atom {
     ///
     /// It fails if for any one of the two atoms the radius (`atom.covalent_bond_radii()`) is not defined.
     pub fn overlaps_bound(&self, other: &Atom) -> Option<bool> {
-        self.covalent_bond_radii()
-            .map(|self_rad| {
-                other
-                    .covalent_bond_radii()
-                    .map(|other_rad| self.distance(other) <= self_rad.0 + other_rad.0)
-            })
-            .flatten()
+        self.covalent_bond_radii().and_then(|self_rad| {
+            other
+                .covalent_bond_radii()
+                .map(|other_rad| self.distance(other) <= self_rad.0 + other_rad.0)
+        })
     }
 
     /// Checks if this Atom overlaps with the given atom. It overlaps if the distance between the atoms is
-    /// less then the sum of the radius from this atom and the other atom. The used radius is `atom.covalent_bond_radii().0`.
-    /// Wrapping around the unit cell if needed. Meaning it will give the shortest distance between the two
+    /// less then the sum of the radii of this atom and the other atom, wrapping around the unit cell if needed.
+    /// The used radius is `atom.covalent_bond_radii().0`. This will give the shortest distance between the two
     /// atoms or any of their copies given a crystal of the size of the given unit cell stretching out to
     /// all sides.
     ///
-    /// Note: the atomic radius used in the bound radius to a single atom, this is similar to the bound radius for double or
+    /// Note: the atomic radius used is the bound radius to a single atom, this is similar to the bound radius for double or
     /// triple bonds but could result in incorrect results.
     ///
-    /// It fails if for any one of the two atoms the radius (`atom.covalent_bond_radii()`) is not defined.
+    /// It returns `None` if for any one of the two atoms the radius (`atom.covalent_bond_radii()`) is not defined.
     pub fn overlaps_bound_wrapping(&self, other: &Atom, cell: &UnitCell) -> Option<bool> {
-        self.covalent_bond_radii()
-            .map(|self_rad| {
-                other.covalent_bond_radii().map(|other_rad| {
-                    self.distance_wrapping(other, cell) <= self_rad.0 + other_rad.0
-                })
-            })
-            .flatten()
+        self.covalent_bond_radii().and_then(|self_rad| {
+            other
+                .covalent_bond_radii()
+                .map(|other_rad| self.distance_wrapping(other, cell) <= self_rad.0 + other_rad.0)
+        })
     }
 }
 
@@ -636,7 +700,7 @@ mod tests {
     #[test]
     fn set_name() {
         let mut a = Atom::new(false, 0, "", 0.0, 0.0, 0.0, 0.0, 0.0, "", 0).unwrap();
-        assert!(a.set_name("Å").is_err());
+        assert!(a.set_name("Å").is_err());
         assert!(a.set_name("ATOMS").is_ok());
         a.set_name("ATOM").unwrap();
         a.set_name("HOH").unwrap();
@@ -666,6 +730,18 @@ mod tests {
         assert_eq!(a.distance_wrapping(&b, &cell), 2.0);
     }
 
+    #[test]
+    fn angles() {
+        let a = Atom::new(false, 0, "", 1.0, 0.0, 0.0, 0.0, 0.0, "C", 0).unwrap();
+        let b = Atom::new(false, 0, "", 0.0, 1.0, 0.0, 0.0, 0.0, "C", 0).unwrap();
+        let c = Atom::new(false, 0, "", 0.0, 0.0, 1.0, 0.0, 0.0, "C", 0).unwrap();
+        let d = Atom::new(false, 0, "", 1.0, 1.0, 1.0, 0.0, 0.0, "C", 0).unwrap();
+        let e = Atom::new(false, 0, "", 0.0, 0.0, 0.0, 0.0, 0.0, "C", 0).unwrap();
+
+        assert!((a.angle(&b, &c) - 60.0).abs() < 0.0001);
+        assert!((a.dihedral(&e, &c, &d) - 45.0).abs() < 0.0001);
+    }
+
     #[test]
     fn distance_all_axes() {
         let a = Atom::new(false, 0, "", 1.0, 1.0, 1.0, 0.0, 0.0, "C", 0).unwrap();
