@@ -1,5 +1,5 @@
 #![allow(dead_code)]
-use crate::transformation::*;
+use crate::transformation::TransformationMatrix;
 use std::cmp::Ordering;
 
 #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
@@ -16,6 +16,7 @@ pub struct MtriX {
 
 impl MtriX {
     /// Create a new MtriX with the given arguments
+    #[must_use]
     pub fn new(
         serial_number: usize,
         transformation: TransformationMatrix,
