@@ -3,8 +3,8 @@ use std::ops;
 
 /// Any parameter to use in a [Search] for atom(s) in a PDB.
 /// For position related searches look into the [rstar] crate which can be combined
-/// with this crate using the `rstar` feature, see [PDB::create_atom_rtree] and
-/// [PDB::create_hierarchy_rtree]. The rstar crate makes spatial lookup and queries
+/// with this crate using the `rstar` feature, see [`PDB::create_atom_rtree`] and
+/// [`PDB::create_hierarchy_rtree`]. The rstar crate makes spatial lookup and queries
 /// way faster and feasible to use in high performance environments.
 #[allow(unused)]
 #[derive(Debug, Clone)]
@@ -12,10 +12,16 @@ use std::ops;
 pub enum Term {
     /// The model serial number, only used in (NMR) PDB files with multiple states of a protein, see [Model::serial_number].
     ModelSerialNumber(usize),
+    /// Search for a range of model serial numbers, starting at the first number and ending with the last number inclusive.
+    ModelSerialNumberRange(usize, usize),
     /// The chain id eg `A`, see [Chain::id].
     ChainId(String),
+    /// Search for a range of chain ids, using the Ord implementation of std::str [https://doc.rust-lang.org/std/primitive.str.html#impl-Ord], starting at the first number and ending with the last number inclusive.
+    ChainIdRange(String, String),
     /// The residue serial number, see [Residue::serial_number].
     ResidueSerialNumber(isize),
+    /// Search for a range of residue serial numbers, starting at the first number and ending with the last number inclusive.
+    ResidueSerialNumberRange(isize, isize),
     /// The residue insertion code eg `Some("A")`, see [Residue::insertion_code].
     ResidueInsertionCode(Option<String>),
     /// The residue serial number and insertion code combined, see [Residue::id].
@@ -42,24 +48,39 @@ pub enum Term {
     Occupancy(f64),
     /// Atom occupancy range starting at the first number and ending with the last number inclusive.
     OccupancyRange(f64, f64),
+    /// Search for backbone atoms, this means that [Conformer::is_amino_acid] is `true` and [Atom::is_backbone] is `true`.
+    Backbone,
+    /// Search for side chain atoms, this means that [Conformer::is_amino_acid] is `true` and [Atom::is_backbone] is `false`.
+    SideChain,
+    /// Search for hetero atoms, this means that [Atom::hetero] is `true`.
+    Hetero,
 }
 
 impl Term {
     fn optional_matches_model(&self, model: &Model) -> Option<bool> {
         match self {
             Term::ModelSerialNumber(s) => Some(*s == model.serial_number()),
+            Term::ModelSerialNumberRange(low, high) => {
+                Some(*low <= model.serial_number() && *high >= model.serial_number())
+            }
             _ => None,
         }
     }
     fn optional_matches_chain(&self, chain: &Chain) -> Option<bool> {
         match self {
             Term::ChainId(s) => Some(s == chain.id()),
+            Term::ChainIdRange(low, high) => {
+                Some(low.as_str() <= chain.id() && high.as_str() >= chain.id())
+            }
             _ => None,
         }
     }
     fn optional_matches_residue(&self, residue: &Residue) -> Option<bool> {
         match self {
             Term::ResidueSerialNumber(s) => Some(*s == residue.serial_number()),
+            Term::ResidueSerialNumberRange(low, high) => {
+                Some(*low <= residue.serial_number() && *high >= residue.serial_number())
+            }
             Term::ResidueInsertionCode(ic) => Some(ic.as_deref() == residue.insertion_code()),
             Term::ResidueId(s, ic) => Some((*s, ic.as_deref()) == residue.id()),
             _ => None,
@@ -72,6 +93,8 @@ impl Term {
                 Some(al.as_deref() == conformer.alternative_location())
             }
             Term::ConformerId(n, al) => Some((n.as_str(), al.as_deref()) == conformer.id()),
+            Term::Backbone if !conformer.is_amino_acid() => Some(false),
+            Term::SideChain if !conformer.is_amino_acid() => Some(false),
             _ => None,
         }
     }
@@ -83,14 +106,17 @@ impl Term {
             }
             Term::AtomName(n) => Some(atom.name() == n),
             Term::Element(e) => Some(atom.element() == e),
-            Term::BFactor(a) => Some(atom.b_factor() == *a),
+            Term::BFactor(a) => Some((atom.b_factor() - *a).abs() < f64::EPSILON),
             Term::BFactorRange(low, high) => {
                 Some(atom.b_factor() >= *low && atom.b_factor() <= *high)
             }
-            Term::Occupancy(a) => Some(atom.occupancy() == *a),
+            Term::Occupancy(a) => Some((atom.occupancy() - *a).abs() < f64::EPSILON),
             Term::OccupancyRange(low, high) => {
                 Some(atom.occupancy() >= *low && atom.occupancy() <= *high)
             }
+            Term::Backbone => Some(atom.is_backbone()),
+            Term::SideChain => Some(!atom.is_backbone()),
+            Term::Hetero => Some(atom.hetero()),
             _ => None,
         }
     }
@@ -136,11 +162,13 @@ impl Search {
     fn simplify(self) -> Search {
         match self {
             Search::Ops(ops, a, b) => match (ops, a.simplify(), b.simplify()) {
-                (Ops::And, Search::Known(false), _) => Search::Known(false),
-                (Ops::And, _, Search::Known(false)) => Search::Known(false),
+                (Ops::And, Search::Known(false), _) | (Ops::And, _, Search::Known(false)) => {
+                    Search::Known(false)
+                }
                 (Ops::And, Search::Known(a), Search::Known(b)) => Search::Known(a & b),
-                (Ops::Or, Search::Known(true), _) => Search::Known(true),
-                (Ops::Or, _, Search::Known(true)) => Search::Known(true),
+                (Ops::Or, Search::Known(true), _) | (Ops::Or, _, Search::Known(true)) => {
+                    Search::Known(true)
+                }
                 (Ops::Or, Search::Known(a), Search::Known(b)) => Search::Known(a | b),
                 (Ops::Xor, Search::Known(a), Search::Known(b)) => Search::Known(a ^ b),
                 (ops, a, b) => Search::Ops(ops, Box::new(a), Box::new(b)),
@@ -154,6 +182,7 @@ impl Search {
     }
 
     /// Check if the search is done.
+    #[must_use]
     pub fn complete(&self) -> Option<bool> {
         match self {
             Search::Known(a) => Some(*a),
@@ -162,6 +191,7 @@ impl Search {
     }
 
     /// Add information about the model into the search, returns a new search with the information integrated
+    #[must_use]
     pub fn add_model_info(&self, model: &Model) -> Search {
         match self {
             Search::Ops(ops, a, b) => Search::Ops(
@@ -181,6 +211,7 @@ impl Search {
     }
 
     /// Add information about the chain into the search, returns a new search with the information integrated
+    #[must_use]
     pub fn add_chain_info(&self, chain: &Chain) -> Search {
         match self {
             Search::Ops(ops, a, b) => Search::Ops(
@@ -200,6 +231,7 @@ impl Search {
     }
 
     /// Add information about the residue into the search, returns a new search with the information integrated
+    #[must_use]
     pub fn add_residue_info(&self, residue: &Residue) -> Search {
         match self {
             Search::Ops(ops, a, b) => Search::Ops(
@@ -219,6 +251,7 @@ impl Search {
     }
 
     /// Add information about the conformer into the search, returns a new search with the information integrated
+    #[must_use]
     pub fn add_conformer_info(&self, conformer: &Conformer) -> Search {
         match self {
             Search::Ops(ops, a, b) => Search::Ops(
@@ -238,6 +271,7 @@ impl Search {
     }
 
     /// Add information about the atom into the search, returns a new search with the information integrated
+    #[must_use]
     pub fn add_atom_info(&self, atom: &Atom) -> Search {
         match self {
             Search::Ops(ops, a, b) => Search::Ops(
