@@ -55,7 +55,8 @@ impl UnitCell {
     pub fn set_a(&mut self, new_a: f64) {
         assert!(
             new_a.is_finite(),
-            "The new a value of this UnitCell is not finite"
+            "The new a value of this UnitCell is not finite. Value: {}",
+            new_a
         );
         self.a = new_a;
     }
@@ -65,7 +66,8 @@ impl UnitCell {
     pub fn set_b(&mut self, new_b: f64) {
         assert!(
             new_b.is_finite(),
-            "The new b value of this UnitCell is not finite"
+            "The new b value of this UnitCell is not finite. Value: {}",
+            new_b
         );
         self.b = new_b;
     }
@@ -75,7 +77,8 @@ impl UnitCell {
     pub fn set_c(&mut self, new_c: f64) {
         assert!(
             new_c.is_finite(),
-            "The new c value of this UnitCell is not finite"
+            "The new c value of this UnitCell is not finite. Value: {}",
+            new_c
         );
         self.c = new_c;
     }
@@ -90,11 +93,14 @@ impl UnitCell {
     pub fn set_alpha(&mut self, new_alpha: f64) {
         assert!(
             new_alpha.is_finite(),
-            "The new alpha value of this UnitCell is not finite"
+            "The new alpha value of this UnitCell is not finite. Value: {}",
+            new_alpha
+        );
+        assert!(
+            (0.0..360.0).contains(&new_alpha),
+            "The new alpha value of this UnitCell is out of bounds [0, 360). Value: {}",
+            new_alpha
         );
-        if !(0.0..360.0).contains(&new_alpha) {
-            panic!("The new alpha value of this UnitCell is out of bounds [0, 360).")
-        }
         self.alpha = new_alpha;
     }
     /// Get the beta angle in degrees
@@ -108,11 +114,14 @@ impl UnitCell {
     pub fn set_beta(&mut self, new_beta: f64) {
         assert!(
             new_beta.is_finite(),
-            "The new beta value of this UnitCell is not finite"
+            "The new beta value of this UnitCell is not finite. Value: {}",
+            new_beta
+        );
+        assert!(
+            (0.0..360.0).contains(&new_beta),
+            "The new beta value of this UnitCell is out of bounds [0, 360).. Value: {}",
+            new_beta
         );
-        if !(0.0..360.0).contains(&new_beta) {
-            panic!("The new beta value of this UnitCell is out of bounds [0, 360).")
-        }
         self.beta = new_beta;
     }
     /// Get the gamma angle in degrees
@@ -126,11 +135,14 @@ impl UnitCell {
     pub fn set_gamma(&mut self, new_gamma: f64) {
         assert!(
             new_gamma.is_finite(),
-            "The new gamma value of this UnitCell is not finite"
+            "The new gamma value of this UnitCell is not finite. Value: {}",
+            new_gamma
+        );
+        assert!(
+            (0.0..360.0).contains(&new_gamma),
+            "The new gamma value of this UnitCell is out of bounds [0, 360).. Value: {}",
+            new_gamma
         );
-        if !(0.0..360.0).contains(&new_gamma) {
-            panic!("The new gamma value of this UnitCell is out of bounds [0, 360).")
-        }
         self.gamma = new_gamma;
     }
     /// Get the dimensions in a tuple (a, b, c)
